<?php

/**
 * @file
 * Hooks provided by the Configuration translation module.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Returns a mapping of configuration name groups to paths and other options.
 *
 * This hook is used to gather a list of configuration name groups and entity
 * mappers tied to paths to introduce translation tabs at various places in
 * core for in-place translation editing on configuration. The data is
 * encapsulated in ConfigGroupMapper instances from
 * Drupal\config_translation\ConfigGroupMapper and ConfigEntityMapper instances
 * from Drupal\config_translation\ConfigEntityMapper.
 *
 * @see config_translation_menu().
 */
function hook_config_translation_group_info() {
  $items = array();

  // Provide menu path for base editing page, title configuration page,
  // array of configuration names to encompass. Optionally provide the created
  // menu item type and whether to include an additional edit tab.
  $items[] = new ConfigGroupMapper('admin/config/development/myconfig', t('My module main configuration'), array('mymodule.config_key'));
  $items[] = new ConfigGroupMapper('admin/config/development/otherconfig', t('My module additional settings'), array('mymodule.other_key', 'mymodule.yet_another_key'), MENU_LOCAL_TASK, TRUE);

  // Provide menu path with path position for entity placeholder, entity
  // machine name, title with @label placeholder for the entity and config name
  // prefix for storage. Optionally provide the created menu item type and
  // whether to include an additional edit tab.
  $items[] = new ConfigEntityMapper('admin/config/development/myconfig/list/%myentity', 5, 'myentity', t('@label my entity'), 'myentity.entity');
  return $items;
}

/**
 * Alters any configuration mappers that have been set up.
 *
 * Useful to extend existing groups with new configuration names, for example
 * when altering existing forms with new settings stored elsewhere. This allows
 * the translation experience to also reflect the compound form element in one
 * screen.
 *
 * @param array $config_mappers
 *   Array of configuration mappers to alter. The array is keyed by paths for
 *   each group (unlike in hook_config_translation_group_info()), for easier
 *   implementation in both hooks.
 */
function hook_config_translation_group_info_alter(&$config_mappers) {
  $path = 'admin/config/development/myconfig';
  if (isset($config_mappers[$path])) {
    $config_mappers[$path]->addName('othermodule.altered_settings_key');
  }
}

/**
 * @} End of "addtogroup hooks".
 */
