<?php

/**
 * @file
 * Contains \Drupal\config_translation\ConfigMapperInterface.
 */

namespace Drupal\config_translation;

interface ConfigMapperInterface {

  /**
   * Returns whether this configuration mapper needs an edit tab.
   *
   * @return bool
   *   TRUE if this mapper needs an edit tab, FALSE otherwise.
   */
  public function hasEditTab();

  /**
   * Returns base path of this configuration mapper.
   *
   * @return string
   *   The mapper base path.
   */
  public function getBasePath();

  /**
   * Returns the menu item type to be used for this mapper.
   *
   * @return int
   *   The menu item type used for this mapper.
   */
  public function getMenuType();

  /**
   * Returns the path ID index if applicable.
   *
   * @return int
   *   The path ID index for the object ID int he path.
   */
  public function getPathIdIndex();

  /**
   * Returns the ConfigGroupMapper instance for this mapper.
   *
   * @param mixed $arg
   *   Menu argument if used with entity mapper.
   *
   * @return \Drupal\config_translation\ConfigGroupMapper
   *   The ConfigGroupMapper instance for this mapper.
   */
  public function getConfigGroup($arg = NULL);

}
